import objectdraw.*;
import java.awt.*;
import java.util.ArrayList;

/**
 * A collection of bricks that can be "hit" by a ball
 * in a pong/breakout game
 * 
 * Jim Teresco, Siena College, CSIS 120, Spring 2012
 *
 * $Id: BrickCollection.java 1846 2012-04-10 15:29:49Z terescoj $
 */
public class BrickCollection {

    private static final double BRICK_SIZE = 25;
    
    private ArrayList<FilledRect> bricks;
    
    /**
     * Constructor for objects of class BrickCollection
     */
    public BrickCollection(double xMin, double xMax, 
                           double yMin, double yMax,
                           int numBricks, DrawingCanvas canvas) {
    
        // place to store our bricks                      
        bricks = new ArrayList<FilledRect>();
        
        RandomDoubleGenerator xGen = 
            new RandomDoubleGenerator(xMin, xMax - BRICK_SIZE);
        RandomDoubleGenerator yGen = 
            new RandomDoubleGenerator(yMin, yMax - BRICK_SIZE);
            
        // randomly place numBricks bricks within the boundaries, making sure
        // none overlap
        int bricksSoFar = 0;
        while (bricksSoFar < numBricks) {
            FilledRect newest = 
                new FilledRect(xGen.nextValue(), yGen.nextValue(),
                    BRICK_SIZE, BRICK_SIZE, canvas);
            bricks.add(newest);
            bricksSoFar++;
        }
    }
    
    // check if the given ball overlaps any of our bricks
    public boolean hit(FilledOval ball) {
        
        for (int brickNum = 0; brickNum < bricks.size(); brickNum++) {
            FilledRect thisBrick = bricks.get(brickNum);
            if (thisBrick.overlaps(ball)) {
                thisBrick.removeFromCanvas();
                bricks.remove(brickNum);
                return true;
            }
        }
        return false;
    }

}
